@@ -63,7 +63,7 @@ public class HeartbeatRequestHeader extends Header {
     private String username = "username";
 
     // PASSWD of the requester
-    private String passwd = "user@123";
+    private String passwd = "default";
 
     @Override
     public Map<String, Object> toMap() {
