@@ -34,7 +34,7 @@ public class RandomLoadBalanceSelectorTest {
     private RandomLoadBalanceSelector<String> randomLoadBalanceSelector;
 
     @BeforeEach
-    public void befor() {
+    public void before() {
         List<String> address = new ArrayList<>();
         address.add("A");
         address.add("B");
