@@ -17,8 +17,8 @@
 
 package org.apache.eventmesh.connector.openfunction.sink.connector;
 
-import org.apache.eventmesh.connector.openfunction.sink.config.OpenFunctionSinkConfig;
-import org.apache.eventmesh.openconnect.api.config.Config;
+import org.apache.eventmesh.common.config.connector.Config;
+import org.apache.eventmesh.common.config.connector.openfunction.OpenFunctionSinkConfig;
 import org.apache.eventmesh.openconnect.api.connector.ConnectorContext;
 import org.apache.eventmesh.openconnect.api.connector.SinkConnectorContext;
 import org.apache.eventmesh.openconnect.api.sink.Sink;
@@ -74,6 +74,11 @@ public class OpenFunctionSinkConnector implements Sink {
         return this.sinkConfig.getSinkConnectorConfig().getConnectorName();
     }
 
+    @Override
+    public void onException(ConnectRecord record) {
+
+    }
+
     @Override
     public void stop() {
     }
