@@ -17,8 +17,8 @@
 
 package org.apache.eventmesh.connector.openfunction.source.connector;
 
-import org.apache.eventmesh.connector.openfunction.source.config.OpenFunctionSourceConfig;
-import org.apache.eventmesh.openconnect.api.config.Config;
+import org.apache.eventmesh.common.config.connector.Config;
+import org.apache.eventmesh.common.config.connector.openfunction.OpenFunctionSourceConfig;
 import org.apache.eventmesh.openconnect.api.connector.ConnectorContext;
 import org.apache.eventmesh.openconnect.api.connector.SourceConnectorContext;
 import org.apache.eventmesh.openconnect.api.source.Source;
@@ -35,12 +35,14 @@ import lombok.extern.slf4j.Slf4j;
 @Slf4j
 public class OpenFunctionSourceConnector implements Source {
 
-    private static final int DEFAULT_BATCH_SIZE = 10;
-
     private OpenFunctionSourceConfig sourceConfig;
 
     private BlockingQueue<ConnectRecord> queue;
 
+    private int maxBatchSize;
+
+    private long maxPollWaitTime;
+
     @Override
     public Class<? extends Config> configClass() {
         return OpenFunctionSourceConfig.class;
@@ -50,7 +52,7 @@ public class OpenFunctionSourceConnector implements Source {
     public void init(Config config) throws Exception {
         // init config for openfunction source connector
         this.sourceConfig = (OpenFunctionSourceConfig) config;
-        this.queue = new LinkedBlockingQueue<>(1000);
+        doInit();
     }
 
     @Override
@@ -58,7 +60,14 @@ public class OpenFunctionSourceConnector implements Source {
         SourceConnectorContext sourceConnectorContext = (SourceConnectorContext) connectorContext;
         // init config for openfunction source connector
         this.sourceConfig = (OpenFunctionSourceConfig) sourceConnectorContext.getSourceConfig();
-        this.queue = new LinkedBlockingQueue<>(1000);
+        doInit();
+    }
+
+    private void doInit() {
+        // init config for openfunction source connector
+        this.queue = new LinkedBlockingQueue<>(sourceConfig.getPollConfig().getCapacity());
+        this.maxBatchSize = sourceConfig.getPollConfig().getMaxBatchSize();
+        this.maxPollWaitTime = sourceConfig.getPollConfig().getMaxWaitTime();
     }
 
     @Override
@@ -76,6 +85,11 @@ public class OpenFunctionSourceConnector implements Source {
         return this.sourceConfig.getSourceConnectorConfig().getConnectorName();
     }
 
+    @Override
+    public void onException(ConnectRecord record) {
+
+    }
+
     @Override
     public void stop() {
 
@@ -87,16 +101,21 @@ public class OpenFunctionSourceConnector implements Source {
 
     @Override
     public List<ConnectRecord> poll() {
+        long startTime = System.currentTimeMillis();
+        long remainingTime = maxPollWaitTime;
 
-        List<ConnectRecord> connectRecords = new ArrayList<>(DEFAULT_BATCH_SIZE);
-
-        for (int count = 0; count < DEFAULT_BATCH_SIZE; ++count) {
+        List<ConnectRecord> connectRecords = new ArrayList<>(maxBatchSize);
+        for (int count = 0; count < maxBatchSize; ++count) {
             try {
-                ConnectRecord connectRecord = queue.poll(3, TimeUnit.SECONDS);
+                ConnectRecord connectRecord = queue.poll(remainingTime, TimeUnit.MILLISECONDS);
                 if (connectRecord == null) {
                     break;
                 }
                 connectRecords.add(connectRecord);
+
+                // calculate elapsed time and update remaining time for next poll
+                long elapsedTime = System.currentTimeMillis() - startTime;
+                remainingTime = maxPollWaitTime > elapsedTime ? maxPollWaitTime - elapsedTime : 0;
             } catch (InterruptedException e) {
                 Thread currentThread = Thread.currentThread();
                 log.warn("[OpenFunctionSourceConnector] Interrupting thread {} due to exception {}",
