@@ -17,7 +17,10 @@
 
 package org.apache.eventmesh.openconnect.api.connector;
 
-import org.apache.eventmesh.openconnect.api.config.SinkConfig;
+import org.apache.eventmesh.common.config.connector.SinkConfig;
+import org.apache.eventmesh.common.remote.job.JobType;
+
+import java.util.Map;
 
 import lombok.Data;
 
@@ -29,4 +32,8 @@ public class SinkConnectorContext implements ConnectorContext {
 
     public SinkConfig sinkConfig;
 
+    public Map<String, Object> runtimeConfig;
+
+    public JobType jobType;
+
 }
