@@ -23,12 +23,15 @@ import org.apache.eventmesh.common.config.ConfigService;
 import org.apache.eventmesh.common.utils.ConfigurationContextUtil;
 import org.apache.eventmesh.runtime.configuration.EventMeshHTTPConfiguration;
 
+import lombok.Getter;
+
 public class EventMeshHttpBootstrap implements EventMeshBootstrap {
 
-    private final EventMeshHTTPConfiguration eventMeshHttpConfiguration;
-
+    @Getter
     public EventMeshHTTPServer eventMeshHttpServer;
 
+    private final EventMeshHTTPConfiguration eventMeshHttpConfiguration;
+
     private final EventMeshServer eventMeshServer;
 
     public EventMeshHttpBootstrap(final EventMeshServer eventMeshServer) {
@@ -64,12 +67,4 @@ public class EventMeshHttpBootstrap implements EventMeshBootstrap {
             eventMeshHttpServer.shutdown();
         }
     }
-
-    public EventMeshHTTPServer getEventMeshHttpServer() {
-        return eventMeshHttpServer;
-    }
-
-    public void setEventMeshHttpServer(EventMeshHTTPServer eventMeshHttpServer) {
-        this.eventMeshHttpServer = eventMeshHttpServer;
-    }
 }
