@@ -25,40 +25,53 @@ import org.apache.eventmesh.common.config.CommonConfiguration;
 import org.apache.eventmesh.common.config.ConfigService;
 import org.apache.eventmesh.common.utils.AssertUtils;
 import org.apache.eventmesh.common.utils.ConfigurationContextUtil;
-import org.apache.eventmesh.common.utils.LogUtils;
+import org.apache.eventmesh.metrics.api.MetricsPluginFactory;
+import org.apache.eventmesh.metrics.api.MetricsRegistry;
 import org.apache.eventmesh.runtime.acl.Acl;
-import org.apache.eventmesh.runtime.admin.controller.ClientManageController;
 import org.apache.eventmesh.runtime.common.ServiceState;
-import org.apache.eventmesh.runtime.constants.EventMeshConstants;
 import org.apache.eventmesh.runtime.core.protocol.http.producer.ProducerTopicManager;
 import org.apache.eventmesh.runtime.meta.MetaStorage;
+import org.apache.eventmesh.runtime.metrics.EventMeshMetricsManager;
+import org.apache.eventmesh.runtime.metrics.MetricsManager;
 import org.apache.eventmesh.runtime.storage.StorageResource;
 import org.apache.eventmesh.runtime.trace.Trace;
 
+import org.apache.commons.collections4.CollectionUtils;
+
 import java.util.List;
 import java.util.Objects;
 import java.util.concurrent.CopyOnWriteArrayList;
+import java.util.stream.Collectors;
 
+import lombok.Getter;
+import lombok.Setter;
 import lombok.extern.slf4j.Slf4j;
 
 @Slf4j
 public class EventMeshServer {
 
+    @Getter
     private final Acl acl;
 
+    @Getter
+    @Setter
     private MetaStorage metaStorage;
 
+    @Getter
     private static Trace trace;
 
     private final StorageResource storageResource;
 
+    @Getter
     private ServiceState serviceState;
 
+    @Getter
     private ProducerTopicManager producerTopicManager;
 
+    @Getter
     private final CommonConfiguration configuration;
 
-    private transient ClientManageController clientManageController;
+    //  private transient ClientManageController clientManageController;
 
     private static final List<EventMeshBootstrap> BOOTSTRAP_LIST = new CopyOnWriteArrayList<>();
 
@@ -66,6 +79,20 @@ public class EventMeshServer {
 
     private static final ConfigService configService = ConfigService.getInstance();
 
+    @Getter
+    private EventMeshTCPServer eventMeshTCPServer = null;
+
+    @Getter
+    private EventMeshHTTPServer eventMeshHTTPServer = null;
+
+    @Getter
+    private EventMeshGrpcServer eventMeshGrpcServer = null;
+
+    @Getter
+    private EventMeshAdminServer eventMeshAdminServer = null;
+
+    private EventMeshMetricsManager eventMeshMetricsManager;
+
     public EventMeshServer() {
 
         // Initialize configuration
@@ -91,8 +118,7 @@ public class EventMeshServer {
                 case GRPC:
                     BOOTSTRAP_LIST.add(new EventMeshGrpcBootstrap(this));
                     break;
-                default:
-                    // nothing to do
+                default: // nothing to do
             }
         }
 
@@ -100,6 +126,16 @@ public class EventMeshServer {
         if (BOOTSTRAP_LIST.isEmpty()) {
             BOOTSTRAP_LIST.add(new EventMeshTcpBootstrap(this));
         }
+
+        // HTTP Admin Server always enabled
+        BOOTSTRAP_LIST.add(new EventMeshAdminBootstrap(this));
+
+        List<String> metricsPluginTypes = configuration.getEventMeshMetricsPluginType();
+        if (CollectionUtils.isNotEmpty(metricsPluginTypes)) {
+            List<MetricsRegistry> metricsRegistries = metricsPluginTypes.stream().map(metric -> MetricsPluginFactory.getMetricsRegistry(metric))
+                .collect(Collectors.toList());
+            eventMeshMetricsManager = new EventMeshMetricsManager(metricsRegistries);
+        }
     }
 
     public void init() throws Exception {
@@ -114,12 +150,6 @@ public class EventMeshServer {
             trace.init();
         }
 
-        EventMeshTCPServer eventMeshTCPServer = null;
-
-        EventMeshGrpcServer eventMeshGrpcServer = null;
-
-        EventMeshHTTPServer eventMeshHTTPServer = null;
-
         // server init
         for (final EventMeshBootstrap eventMeshBootstrap : BOOTSTRAP_LIST) {
             eventMeshBootstrap.init();
@@ -132,22 +162,42 @@ public class EventMeshServer {
             if (eventMeshBootstrap instanceof EventMeshGrpcBootstrap) {
                 eventMeshGrpcServer = ((EventMeshGrpcBootstrap) eventMeshBootstrap).getEventMeshGrpcServer();
             }
+            if (eventMeshBootstrap instanceof EventMeshAdminBootstrap) {
+                eventMeshAdminServer = ((EventMeshAdminBootstrap) eventMeshBootstrap).getEventMeshAdminServer();
+            }
         }
 
-        if (Objects.nonNull(eventMeshTCPServer) && Objects.nonNull(eventMeshHTTPServer) && Objects.nonNull(eventMeshGrpcServer)) {
-
-            clientManageController = new ClientManageController(eventMeshTCPServer, eventMeshHTTPServer, eventMeshGrpcServer, metaStorage);
-            clientManageController.setAdminWebHookConfigOperationManage(eventMeshTCPServer.getAdminWebHookConfigOperationManage());
+        if (Objects.nonNull(eventMeshTCPServer)) {
+            MetricsManager metricsManager = eventMeshTCPServer.getEventMeshTcpMetricsManager();
+            addMetricsManagerAndMetrics(metricsManager);
         }
 
-        final String eventStore = System.getProperty(EventMeshConstants.EVENT_STORE_PROPERTIES, System.getenv(EventMeshConstants.EVENT_STORE_ENV));
+        if (Objects.nonNull(eventMeshGrpcServer)) {
+            MetricsManager metricsManager = eventMeshGrpcServer.getEventMeshGrpcMetricsManager();
+            addMetricsManagerAndMetrics(metricsManager);
+        }
+
+        if (Objects.nonNull(eventMeshHTTPServer)) {
+            MetricsManager metricsManager = eventMeshHTTPServer.getEventMeshHttpMetricsManager();
+            addMetricsManagerAndMetrics(metricsManager);
+        }
+
+        if (Objects.nonNull(eventMeshMetricsManager)) {
+            eventMeshMetricsManager.init();
+        }
 
-        LogUtils.info(log, "eventStore : {}", eventStore);
         producerTopicManager = new ProducerTopicManager(this);
         producerTopicManager.init();
-        serviceState = ServiceState.INITED;
 
-        LogUtils.info(log, SERVER_STATE_MSG, serviceState);
+        serviceState = ServiceState.INITED;
+        log.info(SERVER_STATE_MSG, serviceState);
+    }
+
+    private void addMetricsManagerAndMetrics(MetricsManager metricsManager) {
+        if (Objects.nonNull(metricsManager)) {
+            this.eventMeshMetricsManager.addMetricManager(metricsManager);
+            this.eventMeshMetricsManager.addMetrics(metricsManager.getMetrics());
+        }
     }
 
     public void start() throws Exception {
@@ -165,18 +215,15 @@ public class EventMeshServer {
             eventMeshBootstrap.start();
         }
 
-        if (Objects.nonNull(clientManageController)) {
-            clientManageController.start();
-        }
         producerTopicManager.start();
-        serviceState = ServiceState.RUNNING;
-        LogUtils.info(log, SERVER_STATE_MSG, serviceState);
 
+        serviceState = ServiceState.RUNNING;
+        log.info(SERVER_STATE_MSG, serviceState);
     }
 
     public void shutdown() throws Exception {
         serviceState = ServiceState.STOPPING;
-        LogUtils.info(log, SERVER_STATE_MSG, serviceState);
+        log.info(SERVER_STATE_MSG, serviceState);
 
         for (final EventMeshBootstrap eventMeshBootstrap : BOOTSTRAP_LIST) {
             eventMeshBootstrap.shutdown();
@@ -197,36 +244,8 @@ public class EventMeshServer {
         }
         producerTopicManager.shutdown();
         ConfigurationContextUtil.clear();
+
         serviceState = ServiceState.STOPPED;
-
-        LogUtils.info(log, SERVER_STATE_MSG, serviceState);
-    }
-
-    public static Trace getTrace() {
-        return trace;
-    }
-
-    public ServiceState getServiceState() {
-        return serviceState;
-    }
-
-    public MetaStorage getMetaStorage() {
-        return metaStorage;
-    }
-
-    public void setMetaStorage(final MetaStorage metaStorage) {
-        this.metaStorage = metaStorage;
-    }
-
-    public Acl getAcl() {
-        return acl;
-    }
-
-    public ProducerTopicManager getProducerTopicManager() {
-        return producerTopicManager;
-    }
-
-    public CommonConfiguration getConfiguration() {
-        return configuration;
+        log.info(SERVER_STATE_MSG, serviceState);
     }
 }
