@@ -57,9 +57,10 @@ public class PublisherService extends PublisherServiceGrpc.PublisherServiceImplB
      */
     @Override
     public void publish(CloudEvent request, StreamObserver<CloudEvent> responseObserver) {
+        String clientId = EventMeshCloudEventUtils.getIp(request);
         log.info("cmd={}|{}|client2eventMesh|from={}|to={}", "publish", EventMeshConstants.PROTOCOL_GRPC,
             EventMeshCloudEventUtils.getIp(request), eventMeshGrpcServer.getEventMeshGrpcConfiguration().getEventMeshIp());
-        eventMeshGrpcServer.getMetricsMonitor().recordReceiveMsgFromClient();
+        eventMeshGrpcServer.getEventMeshGrpcMetricsManager().recordReceiveMsgFromClient(clientId);
 
         EventEmitter<CloudEvent> emitter = new EventEmitter<>(responseObserver);
         threadPoolExecutor.submit(() -> {
@@ -84,10 +85,11 @@ public class PublisherService extends PublisherServiceGrpc.PublisherServiceImplB
      */
     @Override
     public void requestReply(CloudEvent request, StreamObserver<CloudEvent> responseObserver) {
+        String clientIp = EventMeshCloudEventUtils.getIp(request);
         log.info("cmd={}|{}|client2eventMesh|from={}|to={}", "RequestReply",
             EventMeshConstants.PROTOCOL_GRPC, EventMeshCloudEventUtils.getIp(request),
             eventMeshGrpcServer.getEventMeshGrpcConfiguration().getEventMeshIp());
-        eventMeshGrpcServer.getMetricsMonitor().recordReceiveMsgFromClient();
+        eventMeshGrpcServer.getEventMeshGrpcMetricsManager().recordReceiveMsgFromClient(clientIp);
 
         EventEmitter<CloudEvent> emitter = new EventEmitter<>(responseObserver);
         threadPoolExecutor.submit(() -> {
@@ -112,10 +114,11 @@ public class PublisherService extends PublisherServiceGrpc.PublisherServiceImplB
      */
     @Override
     public void batchPublish(CloudEventBatch request, StreamObserver<CloudEvent> responseObserver) {
+        String clientIp = EventMeshCloudEventUtils.getIp(request.getEvents(0));
         log.info("cmd={}|{}|client2eventMesh|from={}|to={}", "BatchPublish",
             EventMeshConstants.PROTOCOL_GRPC, null,
             eventMeshGrpcServer.getEventMeshGrpcConfiguration().getEventMeshIp());
-        eventMeshGrpcServer.getMetricsMonitor().recordReceiveMsgFromClient(request.getEventsCount());
+        eventMeshGrpcServer.getEventMeshGrpcMetricsManager().recordReceiveMsgFromClient(request.getEventsCount(), clientIp);
 
         EventEmitter<CloudEvent> emitter = new EventEmitter<>(responseObserver);
         threadPoolExecutor.submit(() -> {
