@@ -27,6 +27,7 @@ import org.apache.commons.lang3.StringUtils;
 
 import java.lang.reflect.Method;
 import java.util.Objects;
+import java.util.concurrent.Executor;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -67,4 +68,9 @@ public interface HttpRequestProcessor {
         return Objects.isNull(extension) ? "" : extension.toString();
     }
 
+    /**
+     * @return {@link Executor}
+     */
+    Executor executor();
+
 }
