@@ -28,7 +28,6 @@ import org.apache.eventmesh.api.exception.OnExceptionContext;
 import org.apache.eventmesh.common.protocol.SubscriptionItem;
 import org.apache.eventmesh.common.protocol.SubscriptionMode;
 import org.apache.eventmesh.common.utils.JsonUtils;
-import org.apache.eventmesh.common.utils.LogUtils;
 import org.apache.eventmesh.runtime.boot.EventMeshTCPServer;
 import org.apache.eventmesh.runtime.configuration.EventMeshTCPConfiguration;
 import org.apache.eventmesh.runtime.constants.EventMeshConstants;
@@ -39,7 +38,7 @@ import org.apache.eventmesh.runtime.core.protocol.tcp.client.session.Session;
 import org.apache.eventmesh.runtime.core.protocol.tcp.client.session.push.DownStreamMsgContext;
 import org.apache.eventmesh.runtime.core.protocol.tcp.client.session.retry.TcpRetryer;
 import org.apache.eventmesh.runtime.core.protocol.tcp.client.session.send.UpStreamMsgContext;
-import org.apache.eventmesh.runtime.metrics.tcp.EventMeshTcpMonitor;
+import org.apache.eventmesh.runtime.metrics.tcp.EventMeshTcpMetricsManager;
 import org.apache.eventmesh.runtime.util.EventMeshUtil;
 import org.apache.eventmesh.runtime.util.HttpTinyClient;
 import org.apache.eventmesh.runtime.util.TraceUtils;
@@ -85,7 +84,7 @@ public class ClientGroupWrapper {
 
     private TcpRetryer tcpRetryer;
 
-    private EventMeshTcpMonitor eventMeshTcpMonitor;
+    private EventMeshTcpMetricsManager eventMeshTcpMetricsManager;
 
     private DownstreamDispatchStrategy downstreamDispatchStrategy;
 
@@ -131,8 +130,8 @@ public class ClientGroupWrapper {
         this.eventMeshTCPServer = eventMeshTCPServer;
         this.eventMeshTCPConfiguration = eventMeshTCPServer.getEventMeshTCPConfiguration();
         this.tcpRetryer = eventMeshTCPServer.getTcpRetryer();
-        this.eventMeshTcpMonitor =
-            Preconditions.checkNotNull(eventMeshTCPServer.getEventMeshTcpMonitor());
+        this.eventMeshTcpMetricsManager =
+            Preconditions.checkNotNull(eventMeshTCPServer.getEventMeshTcpMetricsManager());
         this.downstreamDispatchStrategy = downstreamDispatchStrategy;
         this.persistentMsgConsumer = new MQConsumerWrapper(eventMeshTCPServer.getEventMeshTCPConfiguration().getEventMeshStoragePluginType());
         this.broadCastMsgConsumer = new MQConsumerWrapper(eventMeshTCPServer.getEventMeshTCPConfiguration().getEventMeshStoragePluginType());
@@ -177,7 +176,6 @@ public class ClientGroupWrapper {
 
             @Override
             public void onSuccess(SendResult sendResult) {
-
             }
 
             @Override
@@ -199,13 +197,13 @@ public class ClientGroupWrapper {
     public boolean addSubscription(SubscriptionItem subscriptionItem, Session session)
         throws Exception {
         if (subscriptionItem == null) {
-            log.error("addSubscription param error,subscriptionItem is null, session:{}", session);
+            log.error("addSubscription param error, subscriptionItem is null, session:{}", session);
             return false;
         }
         String topic = subscriptionItem.getTopic();
         if (session == null || !StringUtils.equalsIgnoreCase(group,
             EventMeshUtil.buildClientGroup(session.getClient().getGroup()))) {
-            log.error("addSubscription param error,topic:{},session:{}", topic, session);
+            log.error("addSubscription param error, topic:{}, session:{}", topic, session);
             return false;
         }
 
@@ -218,11 +216,11 @@ public class ClientGroupWrapper {
             }
             Session s = topic2sessionInGroupMapping.get(topic).putIfAbsent(session.getSessionId(), session);
             if (s == null) {
-                LogUtils.info(log, "Cache session success, group:{} topic:{} client:{} sessionId:{}", group,
-                    topic, session.getClient(), session.getSessionId());
+                log.info("Cache session success, group:{} topic:{} client:{} sessionId:{}",
+                    group, topic, session.getClient(), session.getSessionId());
             } else {
-                LogUtils.warn(log, "Session already exists in topic2sessionInGroupMapping. group:{} topic:{} client:{} sessionId:{}", group, topic,
-                    session.getClient(), session.getSessionId());
+                log.warn("Session already exists in topic2sessionInGroupMapping. group:{} topic:{} client:{} sessionId:{}",
+                    group, topic, session.getClient(), session.getSessionId());
             }
 
             subscriptions.putIfAbsent(topic, subscriptionItem);
@@ -245,7 +243,7 @@ public class ClientGroupWrapper {
         }
         String topic = subscriptionItem.getTopic();
         if (session == null || !StringUtils.equalsIgnoreCase(group, EventMeshUtil.buildClientGroup(session.getClient().getGroup()))) {
-            log.error("removeSubscription param error,topic:{},session:{}", topic, session);
+            log.error("removeSubscription param error, topic:{}, session:{}", topic, session);
             return false;
         }
 
@@ -254,18 +252,11 @@ public class ClientGroupWrapper {
             this.groupLock.writeLock().lockInterruptibly();
             if (topic2sessionInGroupMapping.containsKey(topic)) {
                 if (topic2sessionInGroupMapping.get(topic).remove(session.getSessionId()) != null) {
-
-                    if (log.isInfoEnabled()) {
-                        log.info(
-                            "removeSubscription remove session success, group:{} topic:{} client:{}",
-                            group, topic, session.getClient());
-                    }
+                    log.info("removeSubscription remove session success, group:{} topic:{} client:{}",
+                        group, topic, session.getClient());
                 } else {
-                    if (log.isWarnEnabled()) {
-                        log.warn(
-                            "Not found session in cache, group:{} topic:{} client:{} sessionId:{}",
-                            group, topic, session.getClient(), session.getSessionId());
-                    }
+                    log.warn("Not found session in cache, group:{} topic:{} client:{} sessionId:{}",
+                        group, topic, session.getClient(), session.getSessionId());
                 }
             }
             if (CollectionUtils.size(topic2sessionInGroupMapping.get(topic)) == 0) {
@@ -298,7 +289,6 @@ public class ClientGroupWrapper {
             .buildMeshTcpClientID(sysId, EventMeshConstants.PURPOSE_PUB_UPPER_CASE,
                 eventMeshTCPConfiguration.getEventMeshCluster()));
 
-        // TODO for defibus
         keyValue.put(EventMeshConstants.EVENT_MESH_IDC, eventMeshTCPConfiguration.getEventMeshIDC());
 
         mqProducerWrapper.init(keyValue);
@@ -326,7 +316,7 @@ public class ClientGroupWrapper {
 
     public boolean addGroupConsumerSession(Session session) {
         if (session == null || !StringUtils.equalsIgnoreCase(group, EventMeshUtil.buildClientGroup(session.getClient().getGroup()))) {
-            log.error("addGroupConsumerSession param error,session:{}", session);
+            log.error("addGroupConsumerSession param error, session:{}", session);
             return false;
         }
 
@@ -335,18 +325,13 @@ public class ClientGroupWrapper {
             this.groupLock.writeLock().lockInterruptibly();
             r = groupConsumerSessions.add(session);
             if (r) {
-
-                if (log.isInfoEnabled()) {
-                    log.info("addGroupConsumerSession success, group:{} client:{}", group,
-                        session.getClient());
-                }
+                log.info("addGroupConsumerSession success, group:{} client:{}", group, session.getClient());
             }
         } catch (Exception e) {
             if (e instanceof InterruptedException) {
                 Thread.currentThread().interrupt();
             }
-            log.error("addGroupConsumerSession error! group:{} client:{}", group,
-                session.getClient(), e);
+            log.error("addGroupConsumerSession error! group:{} client:{}", group, session.getClient(), e);
         } finally {
             this.groupLock.writeLock().unlock();
         }
@@ -355,7 +340,7 @@ public class ClientGroupWrapper {
 
     public boolean addGroupProducerSession(Session session) {
         if (session == null || !StringUtils.equalsIgnoreCase(group, EventMeshUtil.buildClientGroup(session.getClient().getGroup()))) {
-            log.error("addGroupProducerSession param error,session:{}", session);
+            log.error("addGroupProducerSession param error, session:{}", session);
             return false;
         }
 
@@ -365,15 +350,13 @@ public class ClientGroupWrapper {
             r = groupProducerSessions.add(session);
             if (r) {
 
-                log.info("addGroupProducerSession success, group:{} client:{}", group,
-                    session.getClient());
+                log.info("addGroupProducerSession success, group:{} client:{}", group, session.getClient());
             }
         } catch (Exception e) {
             if (e instanceof InterruptedException) {
                 Thread.currentThread().interrupt();
             }
-            log.error("addGroupProducerSession error! group:{} client:{}", group,
-                session.getClient(), e);
+            log.error("addGroupProducerSession error! group:{} client:{}", group, session.getClient(), e);
         } finally {
             this.groupLock.writeLock().unlock();
         }
@@ -382,7 +365,7 @@ public class ClientGroupWrapper {
 
     public boolean removeGroupConsumerSession(Session session) {
         if (session == null || !StringUtils.equalsIgnoreCase(group, EventMeshUtil.buildClientGroup(session.getClient().getGroup()))) {
-            log.error("removeGroupConsumerSession param error,session:{}", session);
+            log.error("removeGroupConsumerSession param error, session:{}", session);
             return false;
         }
 
@@ -391,18 +374,13 @@ public class ClientGroupWrapper {
             this.groupLock.writeLock().lockInterruptibly();
             r = groupConsumerSessions.remove(session);
             if (r) {
-
-                if (log.isInfoEnabled()) {
-                    log.info("removeGroupConsumerSession success, group:{} client:{}", group,
-                        session.getClient());
-                }
+                log.info("removeGroupConsumerSession success, group:{} client:{}", group, session.getClient());
             }
         } catch (Exception e) {
             if (e instanceof InterruptedException) {
                 Thread.currentThread().interrupt();
             }
-            log.error("removeGroupConsumerSession error! group:{} client:{}", group,
-                session.getClient(), e);
+            log.error("removeGroupConsumerSession error! group:{} client:{}", group, session.getClient(), e);
         } finally {
             this.groupLock.writeLock().unlock();
         }
@@ -411,7 +389,7 @@ public class ClientGroupWrapper {
 
     public boolean removeGroupProducerSession(Session session) {
         if (session == null || !StringUtils.equalsIgnoreCase(group, EventMeshUtil.buildClientGroup(session.getClient().getGroup()))) {
-            log.error("removeGroupProducerSession param error,session:{}", session);
+            log.error("removeGroupProducerSession param error, session:{}", session);
             return false;
         }
 
@@ -421,15 +399,13 @@ public class ClientGroupWrapper {
             r = groupProducerSessions.remove(session);
             if (r) {
 
-                log.info("removeGroupProducerSession success, group:{} client:{}", group,
-                    session.getClient());
+                log.info("removeGroupProducerSession success, group:{} client:{}", group, session.getClient());
             }
         } catch (Exception e) {
             if (e instanceof InterruptedException) {
                 Thread.currentThread().interrupt();
             }
-            log.error("removeGroupProducerSession error! group:{} client:{}", group,
-                session.getClient(), e);
+            log.error("removeGroupProducerSession error! group:{} client:{}", group, session.getClient(), e);
         } finally {
             this.groupLock.writeLock().unlock();
         }
@@ -461,8 +437,7 @@ public class ClientGroupWrapper {
                 EventMeshTraceConstants.TRACE_DOWNSTREAM_EVENTMESH_SERVER_SPAN, false);
 
             try {
-                eventMeshTcpMonitor.getTcpSummaryMetrics().getMq2eventMeshMsgNum()
-                    .incrementAndGet();
+                eventMeshTcpMetricsManager.mq2eventMeshMsgNumIncrement();
                 event = CloudEventBuilder.from(event)
                     .withExtension(EventMeshConstants.REQ_MQ2EVENTMESH_TIMESTAMP,
                         String.valueOf(System.currentTimeMillis()))
@@ -535,9 +510,7 @@ public class ClientGroupWrapper {
         persistentMsgConsumer.registerEventListener(listener);
 
         inited4Persistent.compareAndSet(false, true);
-        if (log.isInfoEnabled()) {
-            log.info("init persistentMsgConsumer success, group:{}", group);
-        }
+        log.info("init persistentMsgConsumer success, group:{}", group);
     }
 
     public synchronized void startClientGroupPersistentConsumer() throws Exception {
@@ -546,9 +519,7 @@ public class ClientGroupWrapper {
         }
         persistentMsgConsumer.start();
         started4Persistent.compareAndSet(false, true);
-        if (log.isInfoEnabled()) {
-            log.info("starting persistentMsgConsumer success, group:{}", group);
-        }
+        log.info("starting persistentMsgConsumer success, group:{}", group);
     }
 
     public synchronized void initClientGroupBroadcastConsumer() throws Exception {
@@ -573,8 +544,7 @@ public class ClientGroupWrapper {
                 EventMeshUtil.getCloudEventExtensionMap(protocolVersion, event),
                 EventMeshTraceConstants.TRACE_DOWNSTREAM_EVENTMESH_SERVER_SPAN, false);
             try {
-                eventMeshTcpMonitor.getTcpSummaryMetrics().getMq2eventMeshMsgNum()
-                    .incrementAndGet();
+                eventMeshTcpMetricsManager.mq2eventMeshMsgNumIncrement();
                 event = CloudEventBuilder.from(event)
                     .withExtension(EventMeshConstants.REQ_MQ2EVENTMESH_TIMESTAMP,
                         String.valueOf(System.currentTimeMillis()))
@@ -586,9 +556,7 @@ public class ClientGroupWrapper {
                 EventMeshAsyncConsumeContext eventMeshAsyncConsumeContext =
                     (EventMeshAsyncConsumeContext) context;
                 if (CollectionUtils.isEmpty(groupConsumerSessions)) {
-                    if (log.isWarnEnabled()) {
-                        log.warn("found no session to downstream broadcast msg");
-                    }
+                    log.warn("found no session to downstream broadcast msg");
                     eventMeshAsyncConsumeContext.commit(EventMeshAction.CommitMessage);
                     return;
                 }
@@ -605,10 +573,7 @@ public class ClientGroupWrapper {
                     Session session = sessionsItr.next();
 
                     if (!session.isAvailable(topic)) {
-                        if (log.isWarnEnabled()) {
-                            log.warn("downstream broadcast msg,session is not available,client:{}",
-                                session.getClient());
-                        }
+                        log.warn("downstream broadcast msg, session is not available, client:{}", session.getClient());
                         continue;
                     }
 
@@ -631,9 +596,7 @@ public class ClientGroupWrapper {
         broadCastMsgConsumer.registerEventListener(listener);
 
         inited4Broadcast.compareAndSet(false, true);
-        if (log.isInfoEnabled()) {
-            log.info("init broadCastMsgConsumer success, group:{}", group);
-        }
+        log.info("init broadCastMsgConsumer success, group:{}", group);
     }
 
     public synchronized void startClientGroupBroadcastConsumer() throws Exception {
@@ -664,9 +627,7 @@ public class ClientGroupWrapper {
     public synchronized void shutdownBroadCastConsumer() throws Exception {
         if (started4Broadcast.get()) {
             broadCastMsgConsumer.shutdown();
-            if (log.isInfoEnabled()) {
-                log.info("broadcast consumer group:{} shutdown...", group);
-            }
+            log.info("broadcast consumer group:{} shutdown...", group);
         }
         started4Broadcast.compareAndSet(true, false);
         inited4Broadcast.compareAndSet(true, false);
@@ -677,9 +638,7 @@ public class ClientGroupWrapper {
 
         if (started4Persistent.get()) {
             persistentMsgConsumer.shutdown();
-            if (log.isInfoEnabled()) {
-                log.info("persistent consumer group:{} shutdown...", group);
-            }
+            log.info("persistent consumer group:{} shutdown...", group);
         }
         started4Persistent.compareAndSet(true, false);
         inited4Persistent.compareAndSet(true, false);
@@ -702,12 +661,12 @@ public class ClientGroupWrapper {
         this.tcpRetryer = tcpRetryer;
     }
 
-    public EventMeshTcpMonitor getEventMeshTcpMonitor() {
-        return eventMeshTcpMonitor;
+    public EventMeshTcpMetricsManager getEventMeshTcpMetricsManager() {
+        return eventMeshTcpMetricsManager;
     }
 
-    public void setEventMeshTcpMonitor(EventMeshTcpMonitor eventMeshTcpMonitor) {
-        this.eventMeshTcpMonitor = eventMeshTcpMonitor;
+    public void setEventMeshTcpMetricsManager(EventMeshTcpMetricsManager eventMeshTcpMetricsManager) {
+        this.eventMeshTcpMetricsManager = eventMeshTcpMetricsManager;
     }
 
     public DownstreamDispatchStrategy getDownstreamDispatchStrategy() {
@@ -730,9 +689,7 @@ public class ClientGroupWrapper {
         HttpTinyClient.HttpResult result = null;
 
         try {
-            if (log.isInfoEnabled()) {
-                log.info("pushMsgToEventMesh,targetUrl:{},msg:{}", targetUrl, msg);
-            }
+            log.info("pushMsgToEventMesh,targetUrl:{},msg:{}", targetUrl, msg);
             List<String> paramValues = new ArrayList<String>();
             paramValues.add(EventMeshConstants.MANAGE_MSG);
             paramValues.add(JsonUtils.toJSONString(msg));
@@ -766,9 +723,7 @@ public class ClientGroupWrapper {
     private void sendMsgBackToBroker(CloudEvent event, String bizSeqNo) throws Exception {
         try {
             String topic = event.getSubject();
-            if (log.isWarnEnabled()) {
-                log.warn("send msg back to broker, bizSeqno:{}, topic:{}", bizSeqNo, topic);
-            }
+            log.warn("send msg back to broker, bizSeqno:{}, topic:{}", bizSeqNo, topic);
 
             long startTime = System.currentTimeMillis();
             long taskExcuteTime = startTime;
@@ -777,31 +732,20 @@ public class ClientGroupWrapper {
 
                     @Override
                     public void onSuccess(SendResult sendResult) {
-
-                        if (log.isInfoEnabled()) {
-                            log.info(
-                                "group:{} consume fail, sendMessageBack success, bizSeqno:{}, "
-                                    + "topic:{}",
-                                group, bizSeqNo, topic);
-                        }
+                        log.info("group:{} consume fail, sendMessageBack success, bizSeqno:{}, topic:{}",
+                            group, bizSeqNo, topic);
                     }
 
                     @Override
                     public void onException(OnExceptionContext context) {
-                        if (log.isWarnEnabled()) {
-                            log.warn(
-                                "group:{} consume fail, sendMessageBack fail, bizSeqno:{},"
-                                    + " topic:{}",
-                                group, bizSeqNo, topic);
-                        }
+                        log.warn("group:{} consume fail, sendMessageBack fail, bizSeqno:{}, topic:{}",
+                            group, bizSeqNo, topic);
                     }
 
                 });
-            eventMeshTcpMonitor.getTcpSummaryMetrics().getEventMesh2mqMsgNum().incrementAndGet();
+            eventMeshTcpMetricsManager.eventMesh2mqMsgNumIncrement();
         } catch (Exception e) {
-            if (log.isWarnEnabled()) {
-                log.warn("try send msg back to broker failed");
-            }
+            log.warn("try send msg back to broker failed");
             throw e;
         }
     }
