@@ -17,7 +17,6 @@
 
 package org.apache.eventmesh.runtime.core.protocol.tcp.client.group.dispatch;
 
-import org.apache.eventmesh.common.utils.LogUtils;
 import org.apache.eventmesh.runtime.core.protocol.tcp.client.session.Session;
 
 import org.apache.commons.collections4.CollectionUtils;
@@ -50,7 +49,7 @@ public class FreePriorityDispatchStrategy implements DownstreamDispatchStrategy
 
             if (session.isIsolated()) {
                 isolatedSessions.add(session);
-                LogUtils.info(log, "session is not available because session is isolated,isolateTime:{},client:{}",
+                log.info("session is not available because session is isolated,isolateTime:{},client:{}",
                     session.getIsolateTime(), session.getClient());
                 continue;
             }
@@ -60,10 +59,10 @@ public class FreePriorityDispatchStrategy implements DownstreamDispatchStrategy
 
         if (CollectionUtils.isEmpty(filtered)) {
             if (CollectionUtils.isEmpty(isolatedSessions)) {
-                LogUtils.warn(log, "all sessions can't downstream msg");
+                log.warn("all sessions can't downstream msg");
                 return null;
             } else {
-                LogUtils.warn(log, "all sessions are isolated,group:{},topic:{}", group, topic);
+                log.warn("all sessions are isolated,group:{},topic:{}", group, topic);
                 filtered.addAll(isolatedSessions);
             }
         }
