@@ -43,8 +43,6 @@ public class UserAgentUtils {
     public static UserAgent createUserAgent() {
         UserAgent userAgent = new UserAgent();
         userAgent.setSubsystem("5123");
-        // userAgent.setPid(UtilAll.getPid());
-        // userAgent.setHost(RemotingUtil.getLocalAddress());
         userAgent.setVersion("2.0.8");
         userAgent.setUsername("username");
         userAgent.setPassword("1234");
@@ -54,13 +52,11 @@ public class UserAgentUtils {
     public static UserAgent createSubUserAgent() {
         UserAgent userAgent = new UserAgent();
         userAgent.setSubsystem("5243");
-        // userAgent.setPid(UtilAll.getPid());
-        // userAgent.setHost(RemotingUtil.getLocalAddress());
         userAgent.setPort(8888);
         userAgent.setVersion("2.0.8");
         userAgent.setUsername("username");
         userAgent.setPassword("1234");
-        userAgent.setPath("/data/app/defibus-acl/");
+        userAgent.setPath("/data/app/acl/");
         userAgent.setPurpose(EventMeshConstants.PURPOSE_SUB);
         return userAgent;
     }
