@@ -17,7 +17,6 @@
 
 package org.apache.eventmesh.runtime.demo;
 
-import org.apache.eventmesh.common.utils.LogUtils;
 import org.apache.eventmesh.common.utils.ThreadUtils;
 import org.apache.eventmesh.runtime.client.common.ClientConstants;
 import org.apache.eventmesh.runtime.client.common.MessageUtils;
@@ -35,7 +34,7 @@ public class AsyncPubClient {
             pubClient.init();
             pubClient.heartbeat();
             pubClient.registerBusiHandler((msg, ctx) -> {
-                LogUtils.info(log, "server good by request: {}", msg);
+                log.info("server good by request: {}", msg);
             });
 
             for (int i = 0; i < 1; i++) {
