@@ -20,7 +20,6 @@ package org.apache.eventmesh.runtime.demo;
 import org.apache.eventmesh.common.protocol.SubscriptionMode;
 import org.apache.eventmesh.common.protocol.SubscriptionType;
 import org.apache.eventmesh.common.protocol.tcp.Command;
-import org.apache.eventmesh.common.utils.LogUtils;
 import org.apache.eventmesh.runtime.client.common.ClientConstants;
 import org.apache.eventmesh.runtime.client.common.MessageUtils;
 import org.apache.eventmesh.runtime.client.impl.SubClientImpl;
@@ -38,7 +37,7 @@ public class SyncSubClient {
             client.justSubscribe(ClientConstants.SYNC_TOPIC, SubscriptionMode.CLUSTERING, SubscriptionType.SYNC);
             client.registerBusiHandler((msg, ctx) -> {
                 if (msg.getHeader().getCommand() == Command.REQUEST_TO_CLIENT) {
-                    LogUtils.info(log, "receive message:{}", msg);
+                    log.info("receive message:{}", msg);
                 }
             });
         }
