@@ -37,7 +37,6 @@ import org.apache.eventmesh.common.protocol.http.common.ProtocolKey;
 import org.apache.eventmesh.common.protocol.http.common.ProtocolVersion;
 import org.apache.eventmesh.common.protocol.http.common.RequestCode;
 import org.apache.eventmesh.common.utils.JsonUtils;
-import org.apache.eventmesh.common.utils.LogUtils;
 
 import java.util.ArrayList;
 import java.util.Collections;
@@ -115,8 +114,8 @@ public class EventMeshHttpConsumer extends AbstractHttpClient implements AutoClo
             try {
                 final List<HeartbeatRequestBody.HeartbeatEntity> heartbeatEntities = topicList.stream().map(subscriptionItem -> {
                     final HeartbeatRequestBody.HeartbeatEntity heartbeatEntity = new HeartbeatRequestBody.HeartbeatEntity();
-                    heartbeatEntity.topic = subscriptionItem.getTopic();
-                    heartbeatEntity.url = subscribeUrl;
+                    heartbeatEntity.setTopic(subscriptionItem.getTopic());
+                    heartbeatEntity.setUrl(subscribeUrl);
                     return heartbeatEntity;
                 }).collect(Collectors.toList());
 
@@ -167,7 +166,7 @@ public class EventMeshHttpConsumer extends AbstractHttpClient implements AutoClo
 
     @Override
     public void close() throws EventMeshException {
-        LogUtils.info(log, "LiteConsumer shutdown begin.");
+        log.info("LiteConsumer shutdown begin.");
         super.close();
 
         if (consumeExecutor != null) {
@@ -175,7 +174,7 @@ public class EventMeshHttpConsumer extends AbstractHttpClient implements AutoClo
         }
         scheduler.shutdown();
 
-        LogUtils.info(log, "LiteConsumer shutdown end.");
+        log.info("LiteConsumer shutdown end.");
     }
 
     private RequestParam buildCommonRequestParam() {
