@@ -19,7 +19,6 @@ package org.apache.eventmesh.client.http.util;
 
 import org.apache.eventmesh.client.http.model.RequestParam;
 import org.apache.eventmesh.common.Constants;
-import org.apache.eventmesh.common.utils.LogUtils;
 
 import org.apache.commons.collections4.MapUtils;
 import org.apache.commons.lang3.StringUtils;
@@ -109,7 +108,7 @@ public final class HttpUtils {
 
         httpPost.setConfig(configBuilder.build());
 
-        LogUtils.debug(log, "{}", httpPost);
+        log.debug("{}", httpPost);
 
         return client.execute(httpPost, responseHandler);
     }
@@ -161,7 +160,7 @@ public final class HttpUtils {
 
         httpGet.setConfig(configBuilder.build());
 
-        LogUtils.debug(log, "{}", httpGet);
+        log.debug("{}", httpGet);
 
         return client.execute(httpGet, responseHandler);
     }
