@@ -17,30 +17,20 @@
 
 package org.apache.eventmesh.api.exception;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 
 public class AclExceptionTest {
 
     @Test
     public void testConstructWithMsg() {
-        try {
-            new AclException("test");
-
-            new AclException(null);
-        } catch (Exception e) {
-            Assert.fail(e.getMessage());
-        }
+        Assertions.assertDoesNotThrow(() -> new AclException("test"));
+        Assertions.assertDoesNotThrow(() -> new AclException(null));
     }
 
     @Test
     public void testConstructWithMsgAndExption() {
-        try {
-            new AclException("test", new Exception("test1"));
-
-            new AclException(null, null);
-        } catch (Exception e) {
-            Assert.fail(e.getMessage());
-        }
+        Assertions.assertDoesNotThrow(() -> new AclException("test", new Exception("test1")));
+        Assertions.assertDoesNotThrow(() -> new AclException(null, null));
     }
 }
