@@ -28,8 +28,7 @@ public class TopicProperties {
     @JsonCreator
     public TopicProperties(
         @JsonProperty("name") String name,
-        @JsonProperty("messageCount") long messageCount
-    ) {
+        @JsonProperty("messageCount") long messageCount) {
         super();
         this.name = name;
         this.messageCount = messageCount;
