@@ -17,8 +17,13 @@
 
 package org.apache.eventmesh.storage.standalone.producer;
 
+import static org.apache.eventmesh.storage.standalone.TestUtils.TEST_TOPIC;
+import static org.apache.eventmesh.storage.standalone.TestUtils.createSubscribe;
+
 import org.apache.eventmesh.api.SendResult;
 import org.apache.eventmesh.storage.standalone.TestUtils;
+import org.apache.eventmesh.storage.standalone.broker.StandaloneBroker;
+import org.apache.eventmesh.storage.standalone.broker.task.Subscribe;
 
 import java.util.Properties;
 
@@ -28,10 +33,13 @@ import org.junit.jupiter.api.Test;
 
 import io.cloudevents.CloudEvent;
 
+
+
 public class StandaloneProducerTest {
 
     private StandaloneProducer standaloneProducer;
 
+
     @BeforeEach
     public void setUp() {
         standaloneProducer = new StandaloneProducer(new Properties());
@@ -61,7 +69,11 @@ public class StandaloneProducerTest {
 
     @Test
     public void testPublish() {
+        StandaloneBroker standaloneBroker = StandaloneBroker.getInstance();
+        standaloneBroker.createTopicIfAbsent(TEST_TOPIC);
         CloudEvent cloudEvent = TestUtils.createDefaultCloudEvent();
+        Subscribe subscribe = createSubscribe(standaloneBroker);
+        subscribe.subscribe();
         SendResult sendResult = standaloneProducer.publish(cloudEvent);
         Assertions.assertNotNull(sendResult);
     }
