@@ -18,7 +18,7 @@
 package org.apache.eventmesh.trace.jaeger.config;
 
 import org.apache.eventmesh.common.config.Config;
-import org.apache.eventmesh.common.config.ConfigFiled;
+import org.apache.eventmesh.common.config.ConfigField;
 
 import lombok.Data;
 
@@ -26,9 +26,9 @@ import lombok.Data;
 @Config(prefix = "eventmesh.trace.jaeger", path = "classPath://jaeger.properties")
 public class JaegerConfiguration {
 
-    @ConfigFiled(field = "ip", notEmpty = true)
+    @ConfigField(field = "ip", notEmpty = true)
     private String eventMeshJaegerIp = "localhost";
 
-    @ConfigFiled(field = "port", notEmpty = true)
+    @ConfigField(field = "port", notEmpty = true)
     private int eventMeshJaegerPort = 14250;
 }
\ No newline at end of file
